import { Input, Layout, Menu, Avatar, Icon, Typography } from "antd";
import React, { useEffect } from "react";
import { useSelector, useDispatch } from "react-redux";
import { Link, Redirect } from "react-router-dom";
import Logout from "../../components/Util/Logout";
// Import styles
import "./NavbarStyle.scss";

import { selectMenuOption } from "../../store/actions/generalActions";

/**
 * Represents the navigation bar at the top of the homepage
 */
function Navbar() {
	// state
	const [search, setSearch] = React.useState("");
	const [searchAction, setSearchAction] = React.useState(false);
	const [logout, setLogout] = React.useState(false);

	const isAuthenticated = useSelector((state) => state.auth.token !== null);
	const username = useSelector((state) => state.auth.username);

	// Get antd sub components
	const { Header } = Layout;
	const { SubMenu } = Menu;
	const { Search } = Input;

	// Get state from redux store
	const selectedMenuItem = useSelector((state) => state.general.selectedMenuOption);
	const dispatch = useDispatch();

	useEffect(() => {
		setSearchAction(false);
	}, [searchAction]);

	if (logout) {
		return <Logout />;
	} else {
		return (
			<Header className="header">
				{isAuthenticated ? (
					<Link to="/profile/projects">
						<b style={{ fontSize: 16, float: "left" }}>AutoPacker</b>
					</Link>
				) : (
					<Link to="/">
						<b style={{ fontSize: 16, float: "left" }}>AutoPacker</b>
					</Link>
				)}
				<Menu mode="horizontal" style={{ lineHeight: "64px", float: "left" }}>
					<Menu.Item>
						<Search
							placeholder="Search users, projects ..."
							onChange={(e) => setSearch(e.target.value)}
							onSearch={() => setSearchAction(true)}
							style={{ width: 200 }}
						/>
					</Menu.Item>
				</Menu>
				{searchAction ? <Redirect to={"/search?q=" + search} /> : <div />}

				{/* Check if user is authenticated */}
				{isAuthenticated ? (
					<Menu
						mode="horizontal"
						selectedKeys={[selectedMenuItem]}
						onClick={(e) => dispatch(selectMenuOption(e.key))}
						style={{ lineHeight: "64px", float: "right" }}
					>
						{/* TODO Uncomment this when we have implemented the functionality for it */}
						{/* <Menu.Item key="bell" style={{}}>
					<Icon type="bell" style={{ margin: 0 }} />
				</Menu.Item> */}

						<SubMenu
							title={
								<div>
									<Avatar
										style={{
											backgroundColor: "#FAF",
										}}
									/>
									<Typography.Text style={{ marginLeft: 10 }}>
										{username}
									</Typography.Text>
								</div>
							}
						>
							<Menu.Item key="1">
								<Link to="/profile/projects">
									<Icon type="folder" />
									Your projects
								</Link>
							</Menu.Item>
							<Menu.Item key="2">
								<Link to="/profile/servers">
									<Icon type="hdd" />
									Your servers
								</Link>
							</Menu.Item>
							<Menu.Item key="3">
								<Link to="/profile/organizations">
									<Icon type="apartment" />
									Your Organizations
								</Link>
							</Menu.Item>
							<Menu.Divider />
							<Menu.Item key="99">
								<Link to="/profile/settings">
									<Icon type="setting" />
									Settings
								</Link>
							</Menu.Item>
							<Menu.Item key="logout" onClick={() => setLogout(true)}>
								<Icon type="logout" />
								Logout
							</Menu.Item>
						</SubMenu>
					</Menu>
				) : (
					<Menu mode="horizontal" style={{ lineHeight: "64px", float: "right" }}>
						<Menu.Item key="signin">
							<Link to="/signin">Sign in</Link>
						</Menu.Item>
					</Menu>
				)}
			</Header>
		);
	}
}

export default Navbar;
