import { Icon, Layout, Menu } from "antd";
import React from "react";
import { connect, useDispatch, useSelector } from "react-redux";
import { Link, Redirect, Route } from "react-router-dom";
import NTNU from "../../assets/image/ntnu.png";
import ProfileAlert from "../../components/CustomAlerts/ProfileAlert";
import Navbar from "../../components/Navbar/Navbar";
// Import custom components
import Logout from "../../components/Util/Logout";
import { selectMenuOption, toggleSubMenuOption } from "../../store/actions/generalActions";
// Import styles
import "../ProfileDashboard/ProfileDashboardStyle.scss";

/**
 * The default layout for a organization dashboard route
 */
function OrganizationDashboardLayout({ children }) {
	// State
	const [collapsed, setCollapsed] = React.useState(false);
	// Get antd sub components
	const { Sider, Content } = Layout;
	const { SubMenu } = Menu;

	// Get state from redux store
	const organizationName = useSelector((state) => state.org.organizationName);
	const selectedMenuItem = useSelector((state) => state.general.selectedMenuOption);
	const openedSubMenus = useSelector((state) => state.general.openedSubMenus);
	const userRole = useSelector((state) => state.auth.role);
	const dispatch = useDispatch();

	if (organizationName == null) {
		return <Redirect to="/profile/organizations" />;
	} else {
		return (
			<Layout>
				{/* Navbar */}
				<Navbar />
				{/* Content */}
				<Layout style={{ minHeight: "95vh" }}>
					<Sider
						width={200}
						style={{ background: "#fff", padding: 0 }}
						collapsible
						collapsed={collapsed}
						onCollapse={() => setCollapsed(!collapsed)}
					>
						<Menu
							theme="dark"
							mode="inline"
							selectedKeys={[selectedMenuItem]}
							openKeys={openedSubMenus}
							// Called when a menu item is clicked
							onClick={(e) => dispatch(selectMenuOption(e.key))}
							// Called when sub-menus are opened or closed
							//onOpenChange={e => dispatch(toggleSubMenuOption(e[0]))}
							// onTitleClick={e => dispatch(toggleSubMenuOption(e.key))}
							style={{ height: "100%", borderRight: 0 }}
						>
							<div style={{ textAlign: "center" }}>
								{/* // TODO Need to change NTNU to use image of organization later on */}
								<img
									style={{ backgroundColor: "white" }}
									className="identicon"
									src={NTNU}
									alt="identicon"
								/>
							</div>
							<SubMenu
								onTitleClick={(e) => dispatch(toggleSubMenuOption(e.key))}
								key="sub1"
								title={
									<span>
										<Icon type="folder" />
										{collapsed ? <div /> : "Projects"}
									</span>
								}
							>
								<Menu.Item key="4">
									<Link to={"/organization/dashboard/" + organizationName}>
										Overview
									</Link>
								</Menu.Item>
								{userRole === "ADMIN" ? (
									<Menu.Item key="5">
										<Link
											to={
												"/organization/project-requests/" + organizationName
											}
										>
											Project Requests
										</Link>
									</Menu.Item>
								) : (
									<div />
								)}
							</SubMenu>
							<SubMenu
								onTitleClick={(e) => dispatch(toggleSubMenuOption(e.key))}
								key="sub2"
								title={
									<span>
										<Icon type="team" />
										{collapsed ? <div /> : "Members"}
									</span>
								}
							>
								<Menu.Item key="6">
									<Link to={"/organization/members/" + organizationName}>
										Overview
									</Link>
								</Menu.Item>
								{userRole === "ADMIN" ? (
									<Menu.Item key="7">
										<Link to={"/organization/applicants/" + organizationName}>
											Applicants
										</Link>
									</Menu.Item>
								) : (
									<div />
								)}
							</SubMenu>
							<SubMenu
								onTitleClick={(e) => dispatch(toggleSubMenuOption(e.key))}
								key="sub3"
								title={
									<span>
										<Icon type="user" />
										{collapsed ? <div /> : "Personal"}
									</span>
								}
							>
								<Menu.Item key="8">
									<Link to={"/organization/submit-project/" + organizationName}>
										Submit Project
									</Link>
								</Menu.Item>
								<Menu.Item key="9">
									<Link to={"/organization/submissions/" + organizationName}>
										Submissions
									</Link>
								</Menu.Item>
							</SubMenu>
						</Menu>
					</Sider>
					<Content>
						<ProfileAlert />
						{children}
					</Content>
				</Layout>
			</Layout>
		);
	}
}

/**
 * The route itself that is used for the profile dashboard related routes
 */
const OrganizationDashboardRoute = ({ component: Component, isAuthenticated, ...rest }) => {
	return (
		<Route
			{...rest}
			render={(props) =>
				isAuthenticated === true ? (
					<OrganizationDashboardLayout>
						<Component {...props} />
					</OrganizationDashboardLayout>
				) : (
					<Logout />
				)
			}
		/>
	);
};

// TODO Change to use redux hooks instead of connect
const mapStateToProps = (state) => {
	return {
		isAuthenticated: state.auth.token !== null,
	};
};

export default connect(mapStateToProps)(OrganizationDashboardRoute);
