import { Icon, Layout, Menu } from "antd";
import React from "react";
import { connect, useDispatch, useSelector } from "react-redux";
import { Link, Route } from "react-router-dom";
import Identicon from "../../assets/image/download.png";
import ProfileAlert from "../../components/CustomAlerts/ProfileAlert";
import Navbar from "../../components/Navbar/Navbar";
// Import custom components
import Logout from "../../components/Util/Logout";
import { selectMenuOption } from "../../store/actions/generalActions";
// Import styles
import "./ProfileDashboardStyle.scss";

/**
 * The default layout for a profile dashboard route
 */
function ProfileDashboardLayout({ children }) {
	const [collapsed, setCollapsed] = React.useState(false);

	// Get antd sub components
	const { Sider, Content } = Layout;
	// Get state from redux store
	const selectedMenuItem = useSelector((state) => state.general.selectedMenuOption);
	const dispatch = useDispatch();

	return (
		<Layout>
			{/* Navbar */}
			<Navbar />
			{/* Content */}

			<Layout style={{ minHeight: "95vh" }}>
				<Sider
					width={200}
					style={{ background: "#fff", padding: 0 }}
					collapsible
					collapsed={collapsed}
					onCollapse={() => setCollapsed(!collapsed)}
				>
					<Menu
						theme="dark"
						mode="inline"
						selectedKeys={[selectedMenuItem]}
						onClick={(e) => dispatch(selectMenuOption(e.key))}
						style={{ height: "100%", borderRight: 0 }}
					>
						<div style={{ textAlign: "center" }}>
							<img className="identicon" src={Identicon} alt="identicon" />
						</div>
						<Menu.Item key="1">
							<Link to="/profile/projects">
								<Icon type="folder" />
								{collapsed ? <div /> : "Your Projects"}
							</Link>
						</Menu.Item>
						<Menu.Item key="2">
							<Link to="/profile/servers">
								<Icon type="hdd" />
								{collapsed ? <div /> : "Your Servers"}
							</Link>
						</Menu.Item>
						<Menu.Item key="3">
							<Link to="/profile/organizations">
								<Icon type="apartment" />
								{collapsed ? <div /> : "Your Organizations"}
							</Link>
						</Menu.Item>
					</Menu>
				</Sider>
				<Content>
					<ProfileAlert />
					{children}
				</Content>
			</Layout>
		</Layout>
	);
}

// TODO Move the onAccountVerification part to the layout instead of route,
// Need to find out how to use connect on two different without exporting both.
/**
 * The route itself that is used for the profile dashboard related routes
 */
const ProfileDashboardRoute = ({ component: Component, isAuthenticated, ...rest }) => {
	return (
		<Route
			{...rest}
			render={(props) =>
				isAuthenticated === true ? (
					<ProfileDashboardLayout>
						<Component {...props} />
					</ProfileDashboardLayout>
				) : (
					<Logout />
				)
			}
		/>
	);
};

// TODO Change to use redux hooks instead of connect
const mapStateToProps = (state) => {
	return {
		isAuthenticated: state.auth.token !== null,
	};
};

export default connect(mapStateToProps)(ProfileDashboardRoute);
