import axios from "axios";
import {
	AUTH_START,
	AUTH_SUCCESS,
	AUTH_FAILED,
	AUTH_LOGOUT,
	AUTH_VERIFICATION,
} from "./actionTypes";
import { setCookie, getCookie, deleteCookie } from "../../util/cookieService";

const authStart = () => {
	return {
		type: AUTH_START,
	};
};

const authSuccess = (idToken) => {
	return {
		type: AUTH_SUCCESS,
		idToken: idToken,
	};
};

const authFailed = (error) => {
	return {
		type: AUTH_FAILED,
		error: error,
	};
};

export const logout = () => {
	deleteCookie("Authorization");
	return {
		type: AUTH_LOGOUT,
	};
};

export const authVerification = () => {
	return {
		type: AUTH_VERIFICATION,
	};
};

/**
 * Performs an authentication attempt to authentication server
 *
 * @param {*} username users' username
 * @param {*} password users' password
 */
export const auth = (username, password) => {
	return (dispatch) => {
		dispatch(authStart());
		const authData = {
			username: username,
			password: password,
		};

		const url =
			process.env.REACT_APP_APPLICATION_URL +
			process.env.REACT_APP_AUTHENTICATION_SERVER +
			"/auth/login";

		axios
			.post(url, authData)
			.then((response) => {
				//console.log(response);
				setCookie(
					"Authorization",
					response.headers.authorization,
					new Date(new Date().getDay())
				);
				dispatch(authSuccess(response.headers.authorization));
				// window.location.replace("/profile/dashboard");
			})
			.catch((err) => {
				//console.log(err);
				// Firebase stuff
				dispatch(authFailed(err));
			});
	};
};

/**
 * Checks the browser for an existing token with name Authorization and stores the token in redux state
 */
export const authCheckState = () => {
	return (dispatch) => {
		const tokenFound = getCookie("Authorization") !== "";
		if (!tokenFound) {
			dispatch(logout());
		} else {
			const token = getCookie("Authorization");
			dispatch(authSuccess(token));
		}
	};
};

export const updateVerification = () => {
	return (dispatch) => {
		const tokenFound = getCookie("Authorization") !== "";
		if (!tokenFound) {
			dispatch(logout());
		} else {
			dispatch(authVerification());
		}
	};
};
