import {
	AUTH_START,
	AUTH_SUCCESS,
	AUTH_FAILED,
	AUTH_LOGOUT,
	AUTH_VERIFICATION,
} from "../actions/actionTypes";
import { updateState } from "../reduxUtil/reduxUtil";
// Supporting methods
import * as jwt_decode from "jwt-decode";
// Custom alert

const initialState = {
	token: null,
	username: null,
	isVerified: null,
	role: null,
	error: null,
	authFail: false,
	loading: false,
};

const authStart = (state) => {
	return updateState(state, {
		error: null,
		loading: true,
	});
};

const authSuccess = (state, action) => {
	return updateState(state, {
		token: action.idToken,
		username: jwt_decode(action.idToken).sub,
		isVerified: jwt_decode(action.idToken).isVerified,
		role: jwt_decode(action.idToken).role,
		error: null,
		loading: false,
	});
};

const authFailed = (state, action) => {
	return updateState(state, {
		error: action.error,
		authFail: true,
		loading: false,
		username: null,
		token: null,
		role: null,
		isVerified: null,
	});
};

const authLogout = (state) => {
	return updateState(state, {
		token: null,
		username: null,
		isVerified: null,
		role: null,
	});
};

const authVerification = (state) => {
	return updateState(state, {
		isVerified: true,
	});
};

const authReducer = (state = initialState, action) => {
	switch (action.type) {
		case AUTH_START:
			return authStart(state);

		case AUTH_SUCCESS:
			return authSuccess(state, action);

		case AUTH_FAILED:
			return authFailed(state, action);

		case AUTH_LOGOUT:
			return authLogout(state);

		case AUTH_VERIFICATION:
			return authVerification(state);

		default:
			return state;
	}
};

export default authReducer;
