import { Col, Icon, Row, Spin } from "antd";
import React, { useEffect } from "react";
import { useSelector } from "react-redux";
import { getCookie } from "../../../../../../util/cookieService";

function Building(props) {
	// Get methods from props
	const { nextStep, setUploadSuccess } = props.methods;

	// Get value from props
	const { setupInfo, file } = props.values;

	// Redux state
	const username = useSelector((state) => state.auth.username);
	const projectName = useSelector((state) => state.general.selectedProjectName);

	useEffect(() => {
		const url =
			process.env.REACT_APP_APPLICATION_URL +
			process.env.REACT_APP_FILE_DELIVERY_API +
			"/projects/" +
			username +
			"/" +
			projectName +
			"/" +
			setupInfo.name +
			"/add";

		//console.log(setupInfo);
		//console.log(file);

		let formData = new FormData();
		formData.append("desc", setupInfo.desc);
		formData.append("config-type", setupInfo["config-type"]);
		formData.append("config-params", '{ "port": ' + setupInfo.port + " }");
		formData.append("module-file", file[0]);

		fetch(url, {
			method: "POST",
			headers: { Authorization: `${getCookie("Authorization")}` },
			body: formData,
		})
			.then(() => {
				nextStep();
				setUploadSuccess(true);
			})
			.catch(() => {
				nextStep();
				setUploadSuccess(false);
			});

		// TODO Make it work with axios
		/* axiosRequest(
			"post",
			url,
			{
				"Content-Type": "multipart/form-data",
			},
			{
				formData,
			},
			() => {
				nextStep();
				setUploadSuccess(true);
			},
			() => {
				nextStep();
				setUploadSuccess(false);
			}
		); */
		// eslint-disable-next-line react-hooks/exhaustive-deps
	}, []);

	return (
		<div>
			<Row>
				<Col xs={24}>
					<Spin
						style={{
							width: "100%",
							marginLeft: "auto",
							marginRight: "auto",
							marginTop: 30,
							marginBottom: 30,
						}}
						indicator={<Icon type="loading" style={{ fontSize: 24 }} spin />}
					/>
				</Col>
			</Row>
		</div>
	);
}

export default Building;
