import {
	Button,
	Form,
	Icon,
	Input,
	Layout,
	PageHeader,
	Radio,
	Tag,
	Tooltip,
	Typography,
} from "antd";
import { TweenOneGroup } from "rc-tween-one";
import React from "react";
import { useDispatch, useSelector } from "react-redux";
import { Redirect } from "react-router-dom";
import { createAlert } from "../../../store/actions/generalActions";
import { axiosRequest } from "../../../util/axiosRequest";

function NewProject(props) {
	const [newProjectName, setProjectName] = React.useState("");
	const [newProjectDescription, setProjectDescription] = React.useState("");
	const [newProjectWebsite, setNewProjectWebsite] = React.useState("");
	const [tags, setTags] = React.useState([]);
	const [tagInput, setTagInput] = React.useState("");
	const [privateProject, setPrivate] = React.useState(false);
	// const [newLicence, setLicence] = React.useState("");
	// const [initREADME, setInitREADME] = React.useState(false);
	// Conditional state
	const [radioChecked, setRadioChecked] = React.useState(false);
	const [redirect, setRedirect] = React.useState(false);

	// validation
	const [validName, setValidName] = React.useState(false);

	// Import sub components from antd
	const { TextArea } = Input;
	const { Content } = Layout;
	const { Paragraph } = Typography;

	const { getFieldDecorator } = props.form;

	const isVerified = useSelector((state) => state.auth.isVerified);
	const dispatch = useDispatch();

	const removeTag = (removedTag) => {
		const tagsa = tags.filter((tag) => tag !== removedTag);
		setTags(tagsa);
	};

	const handleTagInputConfirm = () => {
		let tagsa = tags;
		if (tagInput && tagsa.indexOf(tagInput) === -1) {
			tagsa = [...tags, tagInput];
		}
		setTags(tagsa);
		setTagInput("");
	};

	const formItemLayout = {
		labelCol: {
			xs: { span: 24 },
			sm: { span: 8 },
		},
		wrapperCol: {
			xs: { span: 24 },
			sm: { span: 16 },
		},
	};

	const routes = [
		{
			path: "profile/dashboard",
			breadcrumbName: "Dashboard",
		},
		{
			path: "profile/projects",
			breadcrumbName: "Your Projects",
		},
		{
			path: "profile/new-project",
			breadcrumbName: "Create new project",
		},
	];

	const handleInputChange = (input, value) => {
		switch (input) {
			case 0:
				setProjectName(value);
				break;

			case 1:
				setProjectDescription(value);
				break;

			case 2:
				setNewProjectWebsite(value);
				break;

			case 3:
				setTagInput(value);
				break;

			// case 4:
			// 	setLicence(value);
			// 	break;

			// case 5:
			// 	setInitREADME(value);
			// 	break;

			default:
		}
	};

	const handleSubmit = (event) => {
		event.preventDefault();

		if (isVerified) {
			const url =
				process.env.REACT_APP_APPLICATION_URL +
				process.env.REACT_APP_FILE_DELIVERY_API +
				"/projects";

			axiosRequest(
				"post",
				url,
				{},
				{
					projectName: newProjectName,
					desc: newProjectDescription,
					website: newProjectWebsite,
					tags: tags,
					isPrivate: privateProject,
					// TODO Uncomment this when we have implemented the functionality for it
					/* license: newLicence,
					initializeREADME: initREADME */
				},
				() => {
					//console.log("OK");
					dispatch(
						createAlert(
							"Project Created",
							"Project has successfully been created. You can now add modules to the project.",
							"success",
							true
						)
					);
					setRedirect(true);
				},
				() => {
					dispatch(
						createAlert(
							"Failed to create project",
							"Failed to create the given project, try again later. If it doesn't work make an issue on GitHub.",
							"error",
							true
						)
					);
				}
			);
		} else {
			dispatch(
				createAlert(
					"Project Creation failed",
					"You can't create a project without verifying your account. Please check your email inbox for a verification email, and follow the instructions.",
					"warning",
					true
				)
			);
		}
	};

	const validateName = (rule, value, callback) => {
		if (value.trim().length <= 0) {
			setValidName(false);
			callback("Please name your project");
		} else if (/^[a-zA-Z0-9-]+$/.test(value)) {
			setValidName(true);
			return callback();
		} else {
			setValidName(false);
			callback(
				"Only letters, numbers and dashes are allowed. Spaces and special characters not allowed"
			);
		}
	};

	return (
		<div style={{ width: "100%" }}>
			<PageHeader
				style={{
					border: "1px solid rgb(235, 237, 240)",
					backgroundColor: "#FFFFFF",
				}}
				title="Create New Project"
				breadcrumb={{ routes }}
			>
				<Paragraph>Fill in the form below to create a new project</Paragraph>
			</PageHeader>
			<Content
				style={{
					margin: "24px 16px",
					padding: 24,
					background: "#fff",
					minHeight: 280,
				}}
			>
				{redirect ? <Redirect to="/profile/projects" /> : <div />}
				<Form {...formItemLayout}>
					<Form.Item
						label="Project Name"
						style={{ marginLeft: "auto", marginRight: "auto", maxWidth: 400 }}
					>
						{getFieldDecorator("name", {
							rules: [
								{
									required: true,
									validator: validateName,
								},
							],
						})(
							<Input onChange={(event) => handleInputChange(0, event.target.value)} />
						)}
					</Form.Item>

					<Form.Item
						label="Project Description"
						style={{ marginLeft: "auto", marginRight: "auto", maxWidth: 400 }}
					>
						<TextArea onChange={(event) => handleInputChange(1, event.target.value)} />
					</Form.Item>
					<Form.Item
						label={
							<span>
								Website&nbsp;
								<Tooltip title="You can link a website affiliated with your project. This can be GitHub link, hosted website link etc.">
									<Icon type="question-circle-o" />
								</Tooltip>
							</span>
						}
						style={{ marginLeft: "auto", marginRight: "auto", maxWidth: 400 }}
					>
						<Input onChange={(event) => handleInputChange(2, event.target.value)} />
					</Form.Item>
					<Form.Item
						label={
							<span>
								Tags&nbsp;
								<Tooltip title="Tags can be used to identify and search for projects">
									<Icon type="question-circle-o" />
								</Tooltip>
							</span>
						}
						style={{ marginLeft: "auto", marginRight: "auto", maxWidth: 400 }}
					>
						<Input
							placeholder='Press "ENTER" to add tag'
							value={tagInput}
							onChange={(event) => handleInputChange(3, event.target.value)}
							onPressEnter={handleTagInputConfirm}
						/>
					</Form.Item>
					<div
						style={{
							marginLeft: "auto",
							marginRight: "auto",
							maxWidth: 400,
							width: "100%",
							textAlign: "center",
							marginBottom: 16,
						}}
					>
						<TweenOneGroup
							enter={{
								scale: 0.8,
								opacity: 0,
								type: "from",
								duration: 100,
								onComplete: (e) => {
									e.target.style = "";
								},
							}}
							leave={{ opacity: 0, width: 0, scale: 0, duration: 200 }}
							appear={false}
						>
							{tags.map((tag) => (
								<span key={tag} style={{ display: "inline-block" }}>
									<Tag
										color="blue"
										closable
										onClose={(e) => {
											e.preventDefault();
											removeTag(tag);
										}}
									>
										{tag}
									</Tag>
								</span>
							))}
						</TweenOneGroup>
					</div>
					<Form.Item
						label={
							<span>
								Private project&nbsp;
								<Tooltip title="Private means only you can access. Public means everyone can access (currently only public projects available)">
									<Icon type="question-circle-o" />
								</Tooltip>
							</span>
						}
						style={{ marginLeft: "auto", marginRight: "auto", maxWidth: 400 }}
					>
						{getFieldDecorator("privateProject", {
							rules: [
								{
									required: true,
								},
							],
							initialValue: "no",
						})(
							<Radio.Group>
								<Radio
									disabled
									value="yes"
									onChange={() => {
										setRadioChecked(true);
										setPrivate(true);
									}}
								>
									Yes
								</Radio>
								<Radio
									value="no"
									onChange={() => {
										setRadioChecked(true);
										setPrivate(false);
									}}
								>
									No
								</Radio>
							</Radio.Group>
						)}
					</Form.Item>
					{/* TODO When we have support for this part, uncomment */}
					{/* <Form.Item>
                        <Checkbox   style={{textAlign: "left", display:"block"}}
                                    justify="left" 
                                    onChange={event => handleInputChange(5, event.target.checked)}
                                    >Initialize with README</Checkbox>
                    </Form.Item>
                    <Form.Item>
                    <Select value={newLicence}
                            placeholder="Licence"
                            style={{width: 50}}
                            value={newLicence}
							onChange={value => handleInputChange(4, value)}>
                        <Option value="Be">Org1</Option>
                        <Option value="nd">Org2</Option>
                        <Option value="ik">Org3</Option>
                    </Select>
                    </Form.Item> */}

					<div
						style={{ width: "100%", textAlign: "center" }}
						onClick={(e) => handleSubmit(e)}
					>
						<Button disabled={!validName} type="primary">
							Create Project
						</Button>
					</div>
				</Form>
			</Content>
		</div>
	);
}

export default Form.create()(NewProject);
