import { Card, Col, Layout, Menu, PageHeader, Row } from "antd";
import React, { useEffect } from "react";
import { axiosRequest } from "../../../util/axiosRequest";
import GeneralSetting from "./components/General/GeneralSetting";

function ProjectSettings(props) {
	// State
	const [activeOption, setActiveOption] = React.useState(1);
	const [project, setProject] = React.useState({});

	const { Content } = Layout;

	useEffect(() => {
		const { pathname } = props.location;
		let arr = pathname.split("/");
		let projectId = arr[3];
		//console.log(arr);
		//console.log(projectId);

		const url =
			process.env.REACT_APP_APPLICATION_URL +
			process.env.REACT_APP_FILE_DELIVERY_API +
			"/project-overview/" +
			projectId;

		axiosRequest(
			"get",
			url,
			{},
			{},
			(response) => {
				//console.log(response);
				setProject(response.data);
			}
			//(error) => console.log(error)
		);
		// eslint-disable-next-line react-hooks/exhaustive-deps
	}, []);

	const routes = [
		{
			path: "profile/dashboard",
			breadcrumbName: "Dashboard",
		},
		{
			path: "profile/projects",
			breadcrumbName: "Your Projects",
		},
		{
			path: "profile/project-overview",
			breadcrumbName: project.projectName,
		},
		{
			path: "profile/project-overview/settings",
			breadcrumbName: "Settings",
		},
	];

	const getActiveMenuOption = () => {
		switch (activeOption) {
			case 1:
				return <GeneralSetting project={project} />;

			default:
				setActiveOption(1);
				return <GeneralSetting project={project} />;
		}
	};

	return (
		<React.Fragment>
			<PageHeader
				style={{
					border: "1px solid rgb(235, 237, 240)",
					backgroundColor: "#FFFFFF",
				}}
				title={project.projectName + " Settings"}
				onBack={() => window.history.back()}
				breadcrumb={{ routes }}
			></PageHeader>
			<Content
				style={{
					margin: "24px 16px",
					padding: 24,
					background: "#fff",
				}}
			>
				<Row gutter={[24, 0]}>
					{/* Settings menu */}
					<Col xs={24} md={7}>
						<Card bodyStyle={{ padding: 0 }} title="Project Settings">
							<Menu style={{ padding: 0 }} mode="inline" defaultSelectedKeys={["1"]}>
								<Menu.Item
									key="1"
									style={{
										margin: 0,
										borderBottom: "1px solid lightgrey",
										borderTop: "1px solid lightgrey",
									}}
									onClick={() => setActiveOption(1)}
								>
									General
								</Menu.Item>
							</Menu>
						</Card>
					</Col>
					{/* Settings Content */}
					<Col xs={24} md={17}>
						{getActiveMenuOption()}
					</Col>
				</Row>
			</Content>
		</React.Fragment>
	);
}

export default ProjectSettings;
