import {
	Avatar,
	Button,
	Card,
	Checkbox,
	Col,
	Empty,
	Icon,
	Layout,
	message,
	Modal,
	PageHeader,
	Row,
	Typography,
	Spin,
} from "antd";
import React, { useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Link } from "react-router-dom";
import { axiosRequest } from "../../../util/axiosRequest";

import { createAlert } from "../../../store/actions/generalActions";

function ServerOverview(props) {
	// State
	const [server, setServer] = React.useState({});
	const [modalOpen, setModalOpen] = React.useState(false);
	const [selectedCard, setSelectedCard] = React.useState(null);
	const [refreshList, setRefreshList] = React.useState(false);
	const [deployingProjects, setDeployingProjects] = React.useState([]);
	const [deployFinished, setDeployFinished] = React.useState(false);

	// Project Deletion
	const [projectToDeleteSelected, setProjectToDeleteSelected] = React.useState(null);
	const [deleteModalOpen, setDeleteModalOpen] = React.useState(false);

	// Installation things
	const [installationModalOpen, setInstallationModalOpen] = React.useState(false);
	const [installationLoading, setInstallationLoading] = React.useState(false);

	// State for project management
	const [serverProjects, setServerProjects] = React.useState(null);
	const [userProjects, setUserProjects] = React.useState([]);
	const [projectModalOpen, setProjectModalOpen] = React.useState(false);
	const [numbSelected, setNumbSelected] = React.useState(0);
	const [checkedProjects, setCheckedProjects] = React.useState([]);

	const username = useSelector((state) => state.auth.username);
	const dispatch = useDispatch();

	// Get antd sub components
	const { Paragraph, Text } = Typography;
	const { Content } = Layout;
	const { Meta } = Card;

	useEffect(() => {
		setSelectedCard(null);
		const { pathname } = props.location;
		let arr = pathname.split("/");
		let serverId = arr[arr.length - 1];

		const url =
			process.env.REACT_APP_APPLICATION_URL +
			process.env.REACT_APP_SERVER_MANAGER +
			"/server/server-overview/" +
			serverId;

		axiosRequest(
			"get",
			url,
			{},
			{},
			(response) => {
				//console.log(response);
				setServer(response.data);
				// TODO iff response contains some projects, fetch them from file system api
				if (response.data.projectIds !== "") {
					let list = [];
					// TODO This logic is really redundant and "heavy", should be replaced in the future
					axiosRequest(
						"get",
						process.env.REACT_APP_APPLICATION_URL +
							process.env.REACT_APP_FILE_DELIVERY_API +
							"/projects",
						{},
						{},
						(resp) => {
							//console.log(resp);
							setUserProjects(resp.data);

							let listContainingServerProjectsAndLoadingState = [];

							resp.data.forEach((project) => {
								//console.log("PROJECT:", project);
								//console.log("PROJECT ID:", project.id);

								response.data.projectIds.split(",").forEach((projectId) => {
									//console.log("PROJECT ID IN COPY:", projectId);
									// eslint-disable-next-line eqeqeq
									if (projectId == project.id) {
										//console.log("ITS A FUCKING MATCH!!!");
										list.push(project);
										listContainingServerProjectsAndLoadingState.push({
											id: project.id,
											loading: false,
										});
									} else {
										// console.log(
										// 	"Project ID:",
										// 	project.id,
										// 	"does not match COPY ID:",
										// 	projectId
										// );
									}
								});
							});
							if (list.length <= 0) {
								//console.log("SERVER PROJECTS SET TO NULL");
								setServerProjects(null);
								setDeployingProjects(null);
							} else {
								//console.log("SERVER PROJECTS SET TO:", list);
								setServerProjects(list);
								setDeployingProjects(listContainingServerProjectsAndLoadingState);
							}
						}
						//(error) => console.log(error)
					);
				}
			}
			//(error) => console.log(error)
		);

		// TODO Might want to take this last part into own method as it might not be relevant for the user all the time

		axiosRequest(
			"get",
			process.env.REACT_APP_APPLICATION_URL +
				process.env.REACT_APP_FILE_DELIVERY_API +
				"/projects",
			{},
			{},
			(response) => {
				//console.log(response);
				setUserProjects(response.data);
				let list = [];
				response.data.forEach((project) => {
					list.push({ id: project.id, checked: false });
				});
				setCheckedProjects(list);
			}
			//(error) => console.log(error)
		);
		// eslint-disable-next-line react-hooks/exhaustive-deps
	}, [refreshList]);

	const updateServerProjects = (projectIds) => {
		axiosRequest(
			"post",
			process.env.REACT_APP_APPLICATION_URL +
				process.env.REACT_APP_SERVER_MANAGER +
				"/server/add-project",
			{},
			{
				server_id: server.serverId,
				project_ids: projectIds,
			},
			(response) => {
				//console.log(response);
				window.location.reload();
			},
			(err) => {
				dispatch(
					createAlert(
						"Project not added",
						"Couldn't add the project(s) to the server",
						"error",
						true
					)
				);
				//console.log(err);
			}
		);
	};

	const toggleCheckedProject = (projectId) => {
		let numbCheckedProjects = 0;
		checkedProjects.forEach((project) => {
			if (project.id === projectId) {
				project.checked = !project.checked;
			}
			if (project.checked) {
				numbCheckedProjects++;
			}
		});
		//console.log(checkedProjects);
		setNumbSelected(numbCheckedProjects);
	};

	const toggleLoadingState = (projectId) => {
		let projectsLoading = deployingProjects;
		projectsLoading.forEach((project) => {
			//console.log(project.id, "===", projectId);
			if (project.id === projectId) {
				//console.log("LOADING MATCH", project);
				projectsLoading[projectsLoading.indexOf(project)].loading = !projectsLoading[
					projectsLoading.indexOf(project)
				].loading;
			}
		});
		//console.log(projectsLoading);
		setDeployingProjects(projectsLoading);
	};

	const getLoadingStateForProject = (projectId) => {
		let loading = false;
		deployingProjects.forEach((project) => {
			if (project.id === projectId) {
				loading = project.loading;
			}
		});
		//console.log("Loading", loading);
		return loading;
	};

	const getProjectCheckedValue = (projectId) => {
		let checked = false;
		checkedProjects.forEach((project) => {
			if (project.id === projectId) {
				checked = project.checked;
			}
		});
		return checked;
	};

	const deployProject = (projectId, projectName) => {
		setDeployFinished(false);
		toggleLoadingState(projectId);
		const url =
			process.env.REACT_APP_APPLICATION_URL +
			process.env.REACT_APP_SERVER_MANAGER +
			"/server/deployProject/" +
			username +
			"/" +
			server.serverId +
			"/" +
			projectName;

		axiosRequest(
			"get",
			url,
			{},
			{},
			() => {
				setDeployFinished(true);
				dispatch(
					createAlert(
						"Project successfully deployed",
						"You can view your project at this address: " + server.ip,
						"success",
						true
					)
				);
				toggleLoadingState(projectId);
			},
			() => {
				dispatch(
					createAlert(
						"Failed to deploy project",
						"Something went wrong while deploying the project. Submit a issue on GitHub for assistance.",
						"error",
						true
					)
				);
			}
		);
	};

	const installEssentials = () => {
		setInstallationModalOpen(false);
		setInstallationLoading(true);
		const url =
			process.env.REACT_APP_APPLICATION_URL +
			process.env.REACT_APP_SERVER_MANAGER +
			"/server/init/" +
			server.serverId;

		axiosRequest(
			"get",
			url,
			{},
			{},
			() => {
				dispatch(
					createAlert(
						"Successfully installed essentials",
						"We have disabled the firewall and installed docker and docker-compose.",
						"success",
						true
					)
				);
				setInstallationLoading(false);
			},
			() => {
				dispatch(
					createAlert(
						"Failed to install essentials",
						"Something went wrong while installing server essential software.",
						"error",
						true
					)
				);
				setInstallationLoading(false);
			}
		);
	};

	const routes = [
		{
			path: "profile/dashboard",
			breadcrumbName: "Dashboard",
		},
		{
			path: "profile/servers",
			breadcrumbName: "Your Servers",
		},
		{
			path: "profile/server-overview",
			breadcrumbName: server.title,
		},
	];

	const title = (
		<div>
			{server.title}
			<Icon style={{ marginLeft: 20 }} type="global" />
			{server.open ? " Public" : " Private"}
		</div>
	);

	let actions = "Actions: Unavailable";
	let statusColor = "blue";
	// switch (server.status) {
	// 	case "on":
	// 		statusColor = "green";
	// 		actions = (
	// 			<p>
	// 				Actions: <span style={{ color: "blue" }}>Stop - Restart</span>
	// 			</p>
	// 		);
	// 		break;

	// 	case "off":
	// 		statusColor = "red";
	// 		actions = (
	// 			<p>
	// 				Actions: <span style={{ color: "blue" }}>Start</span>
	// 			</p>
	// 		);
	// 		break;

	// 	case "restart":
	// 		statusColor = "blue";
	// 		actions = (
	// 			<p>
	// 				Actions: <span style={{ color: "blue" }}>Stop - Restart</span>
	// 			</p>
	// 		);
	// 		break;

	// 	default:
	// 		statusColor = "#fcd700";
	// 		actions = "Actions: Unavailable";
	// 		break;
	// }

	const handleProjectSubmit = () => {
		let projectIds = "";
		checkedProjects.forEach((project) => {
			if (project.checked) {
				if (projectIds === "") {
					projectIds += project.id;
				} else {
					projectIds += "," + project.id;
				}
			}
		});
		updateServerProjects(projectIds);
		//console.log(projectIds);
		setProjectModalOpen(false);
	};

	const selectModalToDelete = (id, name) => {
		setProjectToDeleteSelected({
			id: id,
			name: name,
		});
		setDeleteModalOpen(true);
	};

	const closeDeleteModal = () => {
		setDeleteModalOpen(false);
		setProjectToDeleteSelected(null);
	};

	const deleteModal = () => {
		const url =
			process.env.REACT_APP_APPLICATION_URL +
			process.env.REACT_APP_SERVER_MANAGER +
			"/server/remove-project";

		axiosRequest(
			"post",
			url,
			{},
			{
				server_id: server.serverId,
				project_id: projectToDeleteSelected.id,
				project_name: projectToDeleteSelected.name,
			},
			() => {
				/* dispatch(
					createAlert(
						"Project successfully deleted",
						"You have successfully deleted the project: " +
							projectToDeleteSelected.name,
						"success",
						true
					)
				); */
				window.location.reload();
				closeDeleteModal();
			},
			() => {
				dispatch(
					createAlert(
						"Failed to delete project",
						"Failed to delete the project: " +
							projectToDeleteSelected.name +
							". Please write an issue on GitHub if this is unresolved",
						"error",
						true
					)
				);
				closeDeleteModal();
			}
		);
	};

	return (
		<div style={{ width: "100%" }}>
			<PageHeader
				style={{
					border: "1px solid rgb(235, 237, 240)",
					backgroundColor: "#FFFFFF",
				}}
				title={title}
				breadcrumb={{ routes }}
				extra={[
					<Button
						key={0}
						type="link"
						style={{ marginLeft: 10, marginRight: 10 }}
						onClick={() => setProjectModalOpen(true)}
					>
						<Icon type="plus-circle" /> Add Project
					</Button>,
					<Link
						key={1}
						style={{ marginLeft: 10, marginRight: 10 }}
						to={"/profile/server-overview/" + server.serverId + "/settings"}
					>
						<Icon type="setting" /> Settings
					</Link>,
				]}
			>
				{server.description !== null ? (
					<Paragraph>{server.description}</Paragraph>
				) : (
					<div />
				)}

				{/* // TODO Maybe implement website (for example domain of project) later */}
				{/* <Paragraph style={{ color: "blue" }}>
					{server.website !== "" ? (
						<a href={server.website} rel="noopener noreferrer" target="_blank">
							<Icon type="global" /> {server.website}
						</a>
					) : (
						<div />
					)}
				</Paragraph> */}
				<div>
					<Paragraph style={{ color: statusColor }}>
						Status: Unavailable{/*server.status*/}
					</Paragraph>
					<Paragraph>
						Username: {server.serverUsername} -{" "}
						{/*Default Password: {server.password} - */}
						IP Address: {server.ip}
					</Paragraph>

					<div>
						<Paragraph style={{ float: "left" }}>{actions}</Paragraph>

						<Button
							onClick={() => setInstallationModalOpen(true)}
							disabled={installationLoading}
							style={{ float: "right" }}
						>
							<Spin spinning={installationLoading}>Install Essentials</Spin>
						</Button>
					</div>
				</div>
			</PageHeader>
			{/* Can add the Content thingy to route to be common, but might want to do something about the breadcrumb thingy */}
			<Content
				style={{
					margin: "24px 16px",
					padding: 24,
					background: "#fff",
				}}
			>
				{serverProjects !== null ? (
					<Row gutter={[24, 24]}>
						{serverProjects.map((project) => (
							<Col xs={24} lg={8} xl={6} key={serverProjects.indexOf(project)}>
								<Spin
									spinning={
										getLoadingStateForProject(project.id) && !deployFinished
									}
								>
									<Card
										onClick={() => setSelectedCard(project)}
										hoverable
										style={{ width: 240 }}
										bodyStyle={{ padding: 0 }}
										actions={[
											<Icon
												style={{ fontSize: 20 }}
												type="caret-right"
												key="upload"
												onClick={() =>
													deployProject(project.id, project.projectName)
												}
											/>,
											/*<Icon
												type="edit"
												key="edit"
												onClick={() => message.success("Edit button hit")}
											/>,*/
											<Icon
												type="delete"
												key="delete"
												onClick={() =>
													selectModalToDelete(
														project.id,
														project.projectName
													)
												}
											/>,
										]}
									>
										<div onClick={() => setModalOpen(true)}>
											<img
												style={{ width: "100%" }}
												alt="Project"
												src={
													"https://res.cloudinary.com/hkf2ycaep/image/fetch/d_project-placeholder.png,f_auto/https:/assets/project-placeholder-b90804f0a659d3f283c62d185d49635da22a5b8bbfb7e985f0d0390201f9d2b1.png"
												}
											/>
											<Meta
												style={{ padding: 20 }}
												title={project.projectName}
												description={
													<Paragraph ellipsis>{project.desc}</Paragraph>
												}
											/>
										</div>
									</Card>
								</Spin>
							</Col>
						))}
					</Row>
				) : (
					<Empty
						imageStyle={{
							height: 150,
						}}
						description="Server contains no projects"
					>
						<Button type="primary" onClick={() => setProjectModalOpen(true)}>
							Add Project(s)
						</Button>
					</Empty>
				)}
				{selectedCard !== null ? (
					<Modal
						title={selectedCard.projectName}
						centered
						visible={modalOpen}
						onCancel={() => setModalOpen(false)}
						footer={[
							<Button key="close" onClick={() => setModalOpen(false)}>
								Close
							</Button>,
						]}
					>
						<img
							style={{ width: "100%" }}
							alt="Project"
							src={
								"https://res.cloudinary.com/hkf2ycaep/image/fetch/d_project-placeholder.png,f_auto/https:/assets/project-placeholder-b90804f0a659d3f283c62d185d49635da22a5b8bbfb7e985f0d0390201f9d2b1.png"
							}
						/>
						<p style={{ marginTop: 20 }}>{module.desc}</p>
						<Paragraph>{selectedCard.desc}</Paragraph>
						<Paragraph>
							{selectedCard.website !== "" ? (
								<a
									href={selectedCard.website}
									target="_blank"
									rel="noopener noreferrer"
								>
									<Icon type="gitlab" /> {selectedCard.website}
								</a>
							) : (
								<div />
							)}
						</Paragraph>
					</Modal>
				) : (
					<div />
				)}

				<Modal
					title="Add existing project(s) to server"
					centered
					visible={projectModalOpen}
					onOk={() => handleProjectSubmit()}
					onCancel={() => setProjectModalOpen(false)}
				>
					<Paragraph>
						{numbSelected} selected of {userProjects.length} available
					</Paragraph>

					{serverProjects === null
						? userProjects.map((project) => (
								<Card
									key={project.id}
									hoverable
									style={{ height: "auto", marginBottom: 10 }}
									size="small"
									onClick={() => toggleCheckedProject(project.id)}
								>
									<div>
										<Avatar
											size="large"
											icon="folder"
											style={{
												float: "left",
												verticalAlign: "middle",
											}}
										></Avatar>
										<div style={{ verticalAlign: "middle" }}>
											<Text style={{ marginLeft: 16 }}>
												{project.projectName}
											</Text>
											<Checkbox
												checked={getProjectCheckedValue(project.id)}
												style={{ float: "right" }}
											/>
										</div>
									</div>
								</Card>
						  ))
						: userProjects.map((project) =>
								serverProjects.includes(project) ? (
									<Card
										key={project.id}
										style={{
											height: "auto",
											marginBottom: 10,
											backgroundColor: "#b5b5b5",
										}}
										size="small"
									>
										<div>
											<Avatar
												size="large"
												icon="folder"
												style={{
													float: "left",
													verticalAlign: "middle",
												}}
											></Avatar>
											<div style={{ verticalAlign: "middle" }}>
												<Text style={{ marginLeft: 16 }}>
													{project.projectName}
												</Text>
												<Checkbox
													checked={true}
													style={{ float: "right" }}
												/>
											</div>
										</div>
									</Card>
								) : (
									<Card
										key={project.id}
										hoverable
										style={{ height: "auto", marginBottom: 10 }}
										size="small"
										onClick={() => toggleCheckedProject(project.id)}
									>
										<div>
											<Avatar
												size="large"
												icon="folder"
												style={{
													float: "left",
													verticalAlign: "middle",
												}}
											></Avatar>
											<div style={{ verticalAlign: "middle" }}>
												<Text style={{ marginLeft: 16 }}>
													{project.projectName}
												</Text>
												<Checkbox
													checked={getProjectCheckedValue(project.id)}
													style={{ float: "right" }}
												/>
											</div>
										</div>
									</Card>
								)
						  )}
				</Modal>
				{/* Delete Modal */}
				{projectToDeleteSelected !== null ? (
					<Modal
						title={'Delete "' + projectToDeleteSelected.name + '"?'}
						centered
						visible={deleteModalOpen}
						onOk={() => deleteModal()}
						okText="Yes"
						okType="danger"
						onCancel={() => closeDeleteModal()}
					>
						<Paragraph>Are you sure you want to delete this project?</Paragraph>
					</Modal>
				) : (
					<div />
				)}
				{/* Installation Modal */}
				{installationModalOpen ? (
					<Modal
						title={"Install Essentials?"}
						centered
						visible={installationModalOpen}
						onOk={() => installEssentials()}
						okText="Yes"
						onCancel={() => setInstallationModalOpen(false)}
					>
						<Paragraph>
							This will disable the server firewall, and download docker and
							docker-compose. These are needed to be able to run projects on the
							server.
						</Paragraph>
					</Modal>
				) : (
					<div />
				)}
			</Content>
		</div>
	);
}

export default ServerOverview;
