import { Avatar, Col, Divider, Input, Layout, Pagination, Row, Tabs, Typography } from "antd";
import axios from "axios";
import React, { useEffect } from "react";
import { Link, Redirect } from "react-router-dom";
import Navbar from "../../components/Navbar/Navbar";

function SearchResult(props) {
	// State
	const [search, setSearch] = React.useState("");
	const [projectsList, setProjectsList] = React.useState([]);
	const [usersList, setUsersList] = React.useState([]);
	const [organizationsList, setOrganizationsList] = React.useState([]);
	const [searchAction, setSearchAction] = React.useState(false);

	// Pagination state for projects
	const [minNumbProjects, setMinNumbProjects] = React.useState(0);
	const [maxNumbProjects, setMaxNumbProjects] = React.useState(10);

	// Pagination state for users
	const [minNumbUsers, setMinNumbUsers] = React.useState(0);
	const [maxNumbUsers, setMaxNumbUsers] = React.useState(10);

	// Pagination state for organizations
	const [minNumbOrganizations, setMinNumbOrganizations] = React.useState(0);
	const [maxNumbOrganizations, setMaxNumbOrganizations] = React.useState(10);

	// Import sub components from antd
	const { Content } = Layout;
	const { Title, Paragraph, Text } = Typography;
	const { Search } = Input;
	const { TabPane } = Tabs;

	// Initialized on mount (TODO Find a better way to do this :P)
	useEffect(() => {
		setSearchAction(false);

		let arr = window.location.href.split("=", 2);
		let query = arr[1];
		setSearch(query);

		/* Fetch projects */

		const projectsUrl =
			process.env.REACT_APP_APPLICATION_URL +
			process.env.REACT_APP_FILE_DELIVERY_API +
			"/projects/search?q=" +
			query;

		axios.get(projectsUrl).then((response) => {
			//console.log(response);
			setProjectsList(response.data);
		});

		/* Fetch Users */

		const usersUrl =
			process.env.REACT_APP_APPLICATION_URL +
			process.env.REACT_APP_AUTHENTICATION_SERVER +
			"/auth/search?q=" +
			query;

		axios.get(usersUrl).then((response) => {
			//console.log(response);
			setUsersList(response.data);
		});

		/* Fetch Organizations */

		const organizationUrl =
			process.env.REACT_APP_APPLICATION_URL +
			process.env.REACT_APP_GENERAL_API +
			"/organization/search?q=" +
			query;

		axios.get(organizationUrl).then((response) => {
			//console.log(response);
			setOrganizationsList(response.data);
		});
	}, [searchAction, props.location]);

	const handleProjectsPaginationChange = (value) => {
		if (value <= 1) {
			setMinNumbProjects(0);
			setMaxNumbProjects(10);
		} else {
			setMinNumbProjects((value - 1) * 10);
			setMaxNumbProjects(value * 10);
		}
	};

	const handleUsersPaginationChange = (value) => {
		if (value <= 1) {
			setMinNumbUsers(0);
			setMaxNumbUsers(10);
		} else {
			setMinNumbUsers((value - 1) * 10);
			setMaxNumbUsers(value * 10);
		}
	};

	const handleOrganizationsPaginationChange = (value) => {
		if (value <= 1) {
			setMinNumbOrganizations(0);
			setMaxNumbOrganizations(10);
		} else {
			setMinNumbOrganizations((value - 1) * 10);
			setMaxNumbOrganizations(value * 10);
		}
	};

	return (
		<React.Fragment>
			<Layout>
				{/* Navbar */}
				<Navbar />
				{/* Content */}
				<Content style={{ backgroundColor: "white" }}>
					<Row>
						<Col span={14} offset={5}>
							<Title style={{ marginTop: 20 }} level={2}>
								Search
							</Title>
							<Divider />
							<Row>
								<Col xs={24}>
									<Search
										value={search}
										placeholder="Search..."
										onChange={(e) => setSearch(e.target.value)}
										onSearch={() => setSearchAction(true)}
										enterButton
									/>
								</Col>
								{searchAction ? <Redirect to={"/search?q=" + search} /> : <div />}
								<Col xs={24}>
									<Tabs defaultActiveKey={"1"}>
										{/* Projects Tab */}
										<TabPane
											tab={"Projects (" + projectsList.length + ")"}
											key="1"
										>
											{projectsList.length <= 0 ? (
												<p>No projects found</p>
											) : (
												<div>
													<Row>
														<Divider />

														{projectsList
															.slice(minNumbProjects, maxNumbProjects)
															.map((project) => (
																<div key={project.id}>
																	<Col gutter={[0, 12]}>
																		<Avatar
																			shape="square"
																			size={56}
																			style={{
																				backgroundColor:
																					"#ff99f7",
																				float: "left",
																				verticalAlign:
																					"middle",
																				marginBottom: 24,
																				marginRight: 12,
																				cursor: "pointer",
																			}}
																		>
																			{project.projectName
																				.charAt(0)
																				.toUpperCase()}
																		</Avatar>
																		<div>
																			<Link
																				to={
																					"/account/" +
																					project.owner +
																					"/project/" +
																					project.id
																				}
																			>
																				<Text
																					strong
																					style={{
																						cursor:
																							"pointer",
																					}}
																				>
																					{project.owner}{" "}
																					/{" "}
																					{
																						project.projectName
																					}
																				</Text>
																			</Link>
																			<Paragraph ellipsis>
																				{project.desc}
																			</Paragraph>
																		</div>
																	</Col>
																	<Divider />
																</div>
															))}
														{projectsList.length > 10 ? (
															<Pagination
																style={{
																	marginBottom: 20,
																	textAlign: "center",
																}}
																defaultCurrent={1}
																defaultPageSize={10}
																onChange={
																	handleProjectsPaginationChange
																}
																total={projectsList.length}
															/>
														) : (
															<div />
														)}
													</Row>
												</div>
											)}
										</TabPane>
										{/* Users Tab */}
										<TabPane tab={"Users (" + usersList.length + ")"} key="2">
											{usersList.length <= 0 ? (
												<p>No projects found</p>
											) : (
												<div>
													<Row>
														<Divider />
														{usersList
															.slice(minNumbUsers, maxNumbUsers)
															.map((user) => (
																<div key={user.id}>
																	<Col gutter={[0, 12]}>
																		<Avatar
																			shape="square"
																			size={56}
																			icon="user"
																			style={{
																				backgroundColor:
																					"#ff99f7",
																				float: "left",
																				verticalAlign:
																					"middle",
																				marginBottom: 24,
																				marginRight: 12,
																				cursor: "pointer",
																			}}
																		/>
																		<div>
																			<Link
																				to={
																					"/account/" +
																					user.username
																				}
																			>
																				<Text
																					strong
																					style={{
																						cursor:
																							"pointer",
																						verticalAlign:
																							"middle",
																					}}
																				>
																					{user.username}
																				</Text>
																			</Link>
																		</div>
																	</Col>
																	<Divider />
																</div>
															))}
														{usersList.length > 10 ? (
															<Pagination
																style={{
																	marginBottom: 20,
																	textAlign: "center",
																}}
																defaultCurrent={1}
																defaultPageSize={10}
																onChange={
																	handleUsersPaginationChange
																}
																total={usersList.length}
															/>
														) : (
															<div />
														)}
													</Row>
												</div>
											)}
										</TabPane>
										{/* Organization Tab */}
										<TabPane
											tab={"Organizations (" + organizationsList.length + ")"}
											key="3"
										>
											{organizationsList.length <= 0 ? (
												<p>No projects found</p>
											) : (
												<div>
													<Row>
														<Divider />
														{organizationsList
															.slice(
																minNumbOrganizations,
																maxNumbOrganizations
															)
															.map((organization) => (
																<div key={organization.id}>
																	<Col gutter={[0, 12]}>
																		<Avatar
																			shape="square"
																			size={56}
																			icon="apartment"
																			style={{
																				backgroundColor:
																					"#ff99f7",
																				float: "left",
																				verticalAlign:
																					"middle",
																				marginBottom: 24,
																				marginRight: 12,
																				cursor: "pointer",
																			}}
																		/>
																		<div>
																			<Link
																				to={
																					"/organization/" +
																					organization.name
																				}
																			>
																				<Text
																					strong
																					style={{
																						cursor:
																							"pointer",
																						verticalAlign:
																							"middle",
																					}}
																				>
																					{
																						organization.name
																					}
																				</Text>
																			</Link>
																			<Paragraph ellipsis>
																				{
																					organization.description
																				}
																			</Paragraph>
																		</div>
																	</Col>
																	<Divider />
																</div>
															))}
														{organizationsList.length > 10 ? (
															<Pagination
																style={{
																	marginBottom: 20,
																	textAlign: "center",
																}}
																defaultCurrent={1}
																defaultPageSize={10}
																onChange={
																	handleOrganizationsPaginationChange
																}
																total={organizationsList.length}
															/>
														) : (
															<div />
														)}
													</Row>
												</div>
											)}
										</TabPane>
									</Tabs>
								</Col>
							</Row>
						</Col>
					</Row>
				</Content>
			</Layout>
		</React.Fragment>
	);
}

export default SearchResult;
