package no.autopacker.commons.security;

import com.auth0.jwt.JWT;
import com.auth0.jwt.JWTVerifier;
import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.exceptions.JWTVerificationException;
import com.auth0.jwt.interfaces.DecodedJWT;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.filter.OncePerRequestFilter;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class JwtTokenAuthenticationFilter extends OncePerRequestFilter {
    @Override
    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response,
                                    FilterChain fs) throws ServletException, IOException {

        if (request.getHeader(JwtConfig.HEADER) != null) {
            String header = request.getHeader(JwtConfig.HEADER);
            if (header != null) {

                if (header == null || !header.startsWith(JwtConfig.TOKEN_PREFIX)) {
                    fs.doFilter(request, response);
                    return;
                }

                String token = header.replace(JwtConfig.TOKEN_PREFIX, "");
                DecodedJWT jwt;

                try {
                    JWTVerifier verifier = JWT
                            .require(Algorithm.HMAC512(JwtConfig.SECRET))
                            .build();
                    jwt = verifier.verify(token);
                } catch (JWTVerificationException je) {
                    response.sendError(403, je.getMessage());
                    fs.doFilter(request, response);
                    return;
                }

                String username = jwt.getSubject();

                if (username != null) {
                    String role = jwt.getClaim("role").asString();
                    List<GrantedAuthority> authorities = new ArrayList<>();
                    authorities.add(new SimpleGrantedAuthority(role));

                    Authentication auth = new UsernamePasswordAuthenticationToken(username, null, authorities);
                    SecurityContextHolder.getContext().setAuthentication(auth);
                }
            }
        }

        // Continue filter execution
        fs.doFilter(request, response);
    }
}
