package no.autopacker.filedeliveryapi.database;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.mongodb.*;
import com.mongodb.client.*;
import no.autopacker.filedeliveryapi.domain.ModuleMeta;
import org.bson.Document;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.configurationprocessor.json.JSONObject;
import org.springframework.core.env.Environment;
import org.springframework.core.env.Profiles;
import org.springframework.stereotype.Repository;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

import static com.mongodb.client.model.Filters.*;

@Repository
public class MongoDb {
    private final MongoDatabase database;
    private final MongoCollection<Document> configCollection;

    @Autowired
    public MongoDb(Environment env) {
        System.out.println("PROPERTY: " + env.getProperty("fdapi.mongodb.url"));
        MongoClientURI uri = new MongoClientURI(env.getProperty("fdapi.mongodb.url"));
        MongoClient cli = new MongoClient(uri);
        database = cli.getDatabase("apConfig");
        configCollection = database.getCollection("configParams");
        System.out.println(findByModuleId(2));
    }

    public boolean save(long moduleId, String jsonString) {
        boolean isSaved;
        ObjectMapper mapper = new ObjectMapper();

        try {
            Map<String, Object> map = mapper.readValue(jsonString, HashMap.class);
            map.put("module_id", moduleId);
            configCollection.insertOne(new Document(map));
            isSaved = true;
        } catch (IOException e) {
            isSaved = false;
        }

        return isSaved;
    }

    public boolean deleteByModuleId(long moduleId) {
        Document configParams = configCollection.find(eq("module_id", moduleId)).first();

        if (configParams != null) {
            configCollection.deleteOne(configParams);
        }

        return true;
    }

    public Document findByModuleId(long moduleId) {
        return configCollection.find(eq("module_id", moduleId)).first();
    }
}
