package no.autopacker.filedeliveryapi.service;

import no.autopacker.filedeliveryapi.FileDeliveryApiApplication;
import no.autopacker.filedeliveryapi.database.DockerfileRepository;
import no.autopacker.filedeliveryapi.domain.ModuleMeta;
import no.autopacker.filedeliveryapi.domain.ProjectMeta;
import no.autopacker.filedeliveryapi.utils.Utils;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.IOException;

@Service
public class DockerService {
	private final static String TOKEN = "a4c0980e-19d4-4700-8821-899a9cce8c24";
	public final static String DOCKER_USER = "coreautopacker";
	private final static String DOCKER_REPO = "docker.io";

	private DockerfileRepository dockerfileRepo;

	@Autowired
	public DockerService(DockerfileRepository dockerfileRepo) throws Exception {
		this.dockerfileRepo = dockerfileRepo;
		loginToDocker();
	}

	private static void loginToDocker() throws Exception {
		if (System.getProperty("os.name").contains("Linux")) {
			// Login to docker
			Runtime
				.getRuntime()
				.exec(new String[]{"echo", TOKEN, "|", "docker", "login", "--username", DOCKER_USER, "--password-stdin", DOCKER_REPO});

			LoggerFactory.getLogger(FileDeliveryApiApplication.class).info("Logged into docker as " + DOCKER_USER);
		}
	}

	public void buildDockerImage(ModuleMeta module, String ownerUsername) throws Exception {
		if (System.getProperty("os.name").contains("Linux")) {
			String location = module.getLocation();

			String dockerFileLocation = dockerfileRepo.findByName(module.getConfigType()).getLocation();

			String moduleImageName = Utils.instance().getModuleImageName(ownerUsername, module.getName());
			Runtime cmd = Runtime.getRuntime();

			// Copy dockerfile from repository and save it inside project dir with the standard name "Dockerfile"
			cmd.exec(new String[]{"cp", dockerFileLocation, location.concat("Dockerfile")}).waitFor();

			// Build docker image (the repo part format: kullsyre/username-module)
			cmd.exec("docker build -t " + DOCKER_USER + "/" + moduleImageName + " " + location).waitFor();

			// Push docker image to repo
			cmd.exec(new String[]{"docker", "push", DOCKER_USER + "/" + moduleImageName.concat(":latest")}).waitFor();
		}
	}
}
