package no.autopacker.general.entity.organization;

import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.persistence.*;
import javax.validation.constraints.NotEmpty;
import java.util.Date;

@Data
@Entity
@NoArgsConstructor
public class ProjectApplication {

    @Id
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Long id;

    private String comment;

    @OneToOne(targetEntity = Member.class, fetch = FetchType.EAGER)
    @JoinColumn(nullable = false, name = "member_id")
    private Member member;

    @OneToOne(targetEntity = Project.class, fetch = FetchType.EAGER)
    @JoinColumn(nullable = false, name = "project_id")
    private Project project;

    @JsonIgnore
    @ManyToOne
    @JoinColumn(name = "organization_id")
    private Organization organization;

    @Temporal(javax.persistence.TemporalType.DATE)
    private Date created;

    private boolean isAccepted;

    public ProjectApplication(Member member, Project project, String comment) {
        this.organization = member.getOrganization();
        this.member = member;
        this.project = project;
        this.comment = comment;
        this.isAccepted = false;
    }

    @PrePersist
    protected void onCreate() {
        this.created = new Date();
    }

}
