package no.autopacker.authenticationserver.entity;

import com.fasterxml.jackson.annotation.JsonIgnore;
import lombok.Data;
import lombok.NoArgsConstructor;
import no.autopacker.authenticationserver.annotation.ValidEmail;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;

import javax.persistence.*;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;

/** Represents a user entity and contains methods for accessing user specific information */
@Data
@Entity
@NoArgsConstructor
public class User implements UserDetails {

  @Id
  @Column(name = "user_id")
  @GeneratedValue(strategy = GenerationType.AUTO)
  private Long id;

  @NotEmpty
  @Size(min = 4, max = 25)
  private String username;

  @JsonIgnore
  @NotEmpty @ValidEmail private String email;

  @JsonIgnore
  @NotEmpty private String password;

  @JsonIgnore
  @OneToOne(targetEntity = Role.class, fetch = FetchType.EAGER)
  @JoinColumn(nullable = false, name = "role_id")
  Role role;

  @JsonIgnore
  private boolean isEnabled;

  @JsonIgnore
  private boolean isVerified;

  @JsonIgnore
  private boolean isAccountNonExpired;

  @JsonIgnore
  private boolean isAccountNonLocked;

  @JsonIgnore
  private boolean isCredentialsNonExpired;

  /**
   * Constructor for objects of type User
   *
   * @param username the users' username
   * @param email the users' email
   * @param password the users' password
   */
  public User(String username, String email, String password, Role role) {
    this.username = username;
    this.email = email;
    this.password = password;
    this.role = role;
    this.isEnabled = true;
    this.isVerified = false;
    this.isAccountNonExpired = true;
    this.isAccountNonLocked = true;
    this.isCredentialsNonExpired = true;
  }

  /**
   * Returns a collection containing the users' authorities
   *
   * @return a collection containing the users' authorities
   */
  @Override
  public Collection<? extends GrantedAuthority> getAuthorities() {
    try {
      return this.role.getAuthorities();
    } catch (NullPointerException npe) {
      return new ArrayList<>();
    }
  }
}
